@@ -21,7 +21,7 @@ use JSON;
 use URI::Template;
 use RDF::LDF::Error;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 {
    my $ua   = RDF::Trine->default_useragent;
    $ua->agent("RDF:::LDF/$RDF::LDF::VERSION " . $ua->_agent);
@@ -589,6 +589,15 @@ __END__
 
 RDF::LDF - Linked Data Fragments client
 
+=begin markdown
+
+# STATUS
+[![Build Status](https://travis-ci.org/phochste/RDF-LDF.png)](https://travis-ci.org/phochste/RDF-LDF)
+[![Coverage Status](https://coveralls.io/repos/phochste/RDF-LDF/badge.svg)](https://coveralls.io/r/phochste/RDF-LDF)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/RDF-LDF.png)](http://cpants.cpanauthors.org/dist/RDF-LDF)
+
+=end markdown
+
 =head1 SYNOPSIS
 
     use RDF::Trine::Store::LDF;
@@ -658,12 +667,11 @@ Patrick Hochstenbach, C<< patrick.hochstenbach at ugent.be >>
 
 Gregory Todd Williams, C<< greg@evilfunhouse.com >>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it under the terms of either: 
-the GNU General Public License as published by the Free Software Foundation; or the Artistic License.
+This software is copyright (c) 2015 by Patrick Hochstenbach.
 
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
 
 =encoding utf8
 
